//
// This example contains programming source code (Sample Code) for your use in learning.  IBM 
// grants you a nonexclusive copyright license to use this Sample Code for the purpose of 
// learning and as an example from which you can generate similar function tailored to your 
// own specific needs. This Sample Code is provided by IBM for illustrative purposes only 
// and has not been thoroughly tested under all conditions.  IBM, therefore, cannot guarantee
// or imply reliability, serviceability, or function of this Sample Code.  IBM provides no 
// program services for this Sample Code.  All Sample Code contained herein is provided to 
// you "AS IS" without any warranties of any kind.  
//
// THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND 
// NON-INFRINGMENT ARE EXPRESSLY DISCLAIMED.  SOME JURISDICTIONS DO NOT ALLOW THE EXCLUSION 
// OF IMPLIED WARRANTIES, SO THE ABOVE EXCLUSIONS MAY NOT APPLY TO YOU.  IN NO EVENT WILL 
// IBM BE LIABLE TO ANY PARTY FOR ANY DIRECT, INDIRECT, SPECIAL OR OTHER CONSEQUENTIAL 
// DAMAGES FOR ANY USE OF THIS SAMPLE CODE INCLUDING, WITHOUT LIMITATION, ANY LOST 
// PROFITS, BUSINESS INTERRUPTION, LOSS OF PROGRAMS OR OTHER DATA ON YOUR INFORMATION 
// HANDLING SYSTEM OR OTHERWISE, EVEN IF WE ARE EXPRESSLY ADVISED OF THE POSSIBILITY OF 
// SUCH DAMAGES.
//
// (C) Copyright IBM Corp. 2001-2003
// All rights reserved.
// US Government Users Restricted Rights -
// Use, duplication, or disclosure restricted
// by GSA ADP Schedule Contract with IBM Corp.
// Licensed Materials - Property of IBM.
//

/*
  IBM WebSphere UDDI Registry - This program is used to load the IBM UDDI Registry with a
				BusinessEntity and a Business Service.
*/

import java.net.*;
import java.util.*;

import com.ibm.uddi4j.wsdl.*;
import com.ibm.uddi4j.wsdl.client.*;
import com.ibm.uddi4j.wsdl.provider.*;
import com.ibm.uddi4j.wsdl.definition.*;

import org.uddi4j.datatype.*;
import org.uddi4j.datatype.business.*;

public class PublishBusinessandService
{
  private static final String AXIS_TRANSPORT_CLASS = "org.uddi4j.transport.ApacheAxisTransport";
  private static final String SOAP_TRANSPORT_CLASS = "org.uddi4j.transport.ApacheSOAPTransport";

  public static void main(String args[]) throws MalformedURLException, UDDIWSDLProxyException
  {
    UDDIWSDLProxy proxy = null;
    try
    {
	if (args.length < 2) {
		System.out.println("Usage is: PulishBusinessandService <userid> <password>");
		System.exit(1);
	}
	String uid = new String(args[0]);
	String pwd = new String(args[1]);

      proxy = new UDDIWSDLProxy(new URL("http://localhost:9080/uddisoap/inquiryapi"),SOAP_TRANSPORT_CLASS);
      proxy.enablePublishInterface("http://localhost:9080/uddisoap/publishapi", uid, pwd);
      // Publish a new business entity with a name, description and no category bag.
      proxy.publish(new ServiceProvider("A BusinessEntity for Web Services Lab","This is a Business Entity",null));

      // Find the business just published
      Vector nameVector = new Vector();
      nameVector.addElement(new Name("A BusinessEntity for Web Services Lab%"));
      ServiceProvider[] sp = proxy.findAllServiceProviders(null,nameVector,null,null,null,null,false);

      if (sp != null)
      {
        for (int i=0;i<sp.length;i++)
          System.out.println(sp[i].getName());
      }

      // Create the service with a WSDL file as input.
      ServiceDefinition sd_txfr = new ServiceDefinition("http://localhost:9080/MyBankWeb/wsdl/com/ibm/mybank/ejb/TransferService.wsdl");
      ServiceDefinition sd_crtacct = new ServiceDefinition("http://localhost:9080/MyBankWeb/wsdl/com/ibm/mybank/ejb/CreateAccountWSService.wsdl");

      // Publish the service interfaces first.
      ServiceInterface[] siList_txfr = sd_txfr.getServiceInterfaceList();
      ServiceInterface[] siList_crtacct = sd_crtacct.getServiceInterfaceList();
      if (siList_txfr != null)
      {
        for (int i=0;i<siList_txfr.length;i++)
          proxy.publish(siList_txfr[i]);
      }
      if (siList_crtacct != null)
      {
        for (int i=0;i<siList_crtacct.length;i++)
          proxy.publish(siList_crtacct[i]);
      }

      // Publish the service.
      proxy.publish(sp[0],sd_txfr);
      System.out.println("Published the TransferFunds service");
      proxy.publish(sp[0],sd_crtacct);
      System.out.println("Published the Create Account service");

    }
    catch (AuthenticationFailureException e)
    {
      System.out.println("AuthenticationFailureException: " + e.getMessage());
      System.out.println(proxy.getInquiryURL());
      System.out.println(proxy.getPublishURL());
      System.out.println(proxy.getUserId());
      System.out.println(proxy.getCred());
    }
    catch (MalformedURLException e)
    {
      System.out.println("MalformedURLException: " + e.getMessage());
    }
    catch (InvalidServiceDefinitionException e)
    {
      System.out.println("InvalidServiceDefinitionException: " + e.getMessage());
    }
    catch (UDDIWSDLProxyException e)
    {
      System.out.println("UDDIWSDLProxyException: " + e.getMessage());
    }
  }
}