<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    version="1.0"
    xmlns:xalan="http://xml.apache.org/xslt">
<xsl:output method="html" encoding="UTF-8" indent="yes" xalan:indent-amount="2"/>
<xsl:strip-space elements="*"/>


  <!--======================================================================-->
  <!-- This file contains an XSLT transformation stylesheet which           -->
  <!-- constructs a result tree from a number of XML sources by filtering   -->
  <!-- reordering and adding arbitrary structure.                     -->
  <!--======================================================================-->


  <!--======================================================================-->
  <!--                          The Root Element                            -->
  <!-- The "Root Element" section specifies which template will be          -->
  <!-- invoked first thus determining the root element of the result tree.  -->
  <!--======================================================================-->

  <xsl:template match="/">
    <xsl:call-template name="html"/>
  </xsl:template>


  <!--======================================================================-->
  <!--                         Remaining Templates                          -->
  <!-- The remaining section defines the template rules. The last template  -->
  <!-- rule is a generic identity transformation used for moving complete   -->
  <!-- tree fragments from an input source to the result tree.              -->
  <!--======================================================================-->

  <!-- Newly-defined element template -->
  <xsl:template name="body">
    <body>
      <h1>
        <xsl:value-of select="'A list of books to be displayed in a web browser via html'"/>
      </h1>
      <xsl:call-template name="table"/>
    </body>
  </xsl:template>

  <!-- Newly-defined element template -->
  <xsl:template name="head">
    <head>
      <title>
        <xsl:value-of select="'title'"/>
      </title>
    </head>
  </xsl:template>

  <!-- Newly-defined element template -->
  <xsl:template name="html">
    <html>
      <xsl:call-template name="head"/>
      <xsl:call-template name="body"/>
    </html>
  </xsl:template>

  <!-- Newly-defined element template -->
  <xsl:template name="table">
    <table>
      <xsl:attribute name="border">
        <xsl:value-of select="'2'"/>
      </xsl:attribute>
      <xsl:apply-templates select="./Books/book">
        <xsl:sort select="@category"
            order="ascending"
            case-order="upper-first"
            data-type="text"/>
        <xsl:sort select="price/text()"
            order="ascending"
            case-order="upper-first"
            data-type="number"/>
      </xsl:apply-templates>
    </table>
  </xsl:template>

  <!-- Composed element template -->
  <xsl:template match="book">
    <tr>
      <td>
        <xsl:value-of select="concat(author/@first, ' ', author/@last)"/>
      </td>
      <td>
        <xsl:value-of select="title/text()"/>
      </td>
      <td>
        <xsl:value-of select="@category"/>
      </td>
      <td>
        <xsl:value-of select="price/text()"/>
      </td>
    </tr>
  </xsl:template>

  <!-- Identity transformation template -->
  <xsl:template match="*|@*|comment()|processing-instruction()|text()">
    <xsl:copy>
      <xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
    </xsl:copy>
  </xsl:template>
</xsl:stylesheet>
